@@ -20,9 +20,32 @@ use warnings;
 
 =pod
 
+#head2 new($options)
+
+	$log = PSGI::Hector::Log->new({
+		'debug' => 1
+	});
+
+Creates a new instance of the logging class
+
+=cut
+
+#########################################################
+sub new{
+	my($class, $options) = @_;
+	my $self = {
+		'__debug' => $options->{'debug'}
+	};
+	bless $self, $class;
+	return $self;
+}
+#########################################################
+
+=pod
+
 =head2 log($message, $severity)
 
-	$h->log('Just testing', 'info');
+	$log->log('Just testing', 'info');
 
 Logs the provided string to STDERR with a prefixed severity.
 
@@ -32,7 +55,7 @@ Logs the provided string to STDERR with a prefixed severity.
 sub log{	#a simple way to log a message to the apache error log
 	my($self, $message, $severity) = @_;
 	$severity = "" unless $severity;
-	return if !$self->getOption('debug') and $severity eq 'debug';	#ignore debug messages when not in debug mode
+	return if !$self->{'__debug'} and $severity eq 'debug';	#ignore debug messages when not in debug mode
 	print STDERR uc($severity) . " - " . $message . "\n";
 }
 #################################################
@@ -49,7 +72,7 @@ Development questions, bug reports, and patches are welcome to the above address
 
 =head1 Copyright
 
-Copyright (c) 2014 MacGyveR. All rights reserved.
+Copyright (c) 2017 MacGyveR. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
