@@ -101,9 +101,9 @@ In this package there are some responses already available for use:
 
 See L<PSGI::Hector::Response::Raw> for details.
 
-=item SimpleTemplate
+=item TemplateToolkit
 
-See L<PSGI::Hector::Response::SimpleTemplate> for details.
+See L<PSGI::Hector::Response::TemplateToolkit> for details.
 
 =back
 
@@ -119,7 +119,7 @@ Development questions, bug reports, and patches are welcome to the above address
 
 =head1 Copyright
 
-Copyright (c) 2014 MacGyveR. All rights reserved.
+Copyright (c) 2017 MacGyveR. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
